from typing import Generator

from sqlalchemy.orm import Session

from app.db.session import SessionLocal


def get_db() -> Generator[Session, None, None]:
    """
    Dependency function for getting a database session.
    
    Yields a database session that is automatically closed when the request is finished.
    """
    db = SessionLocal()
    try:
        yield db
    finally:
        db.close()